Index: ui/events/ozone/evdev/cursor_delegate_evdev.h |
diff --git a/ui/events/ozone/evdev/cursor_delegate_evdev.h b/ui/events/ozone/evdev/cursor_delegate_evdev.h |
index bba23d19be5f3a93e3f6d00b315079ca8a434b40..6a6820fe74abd9d921dbf4733375807ccc7efdc8 100644 |
--- a/ui/events/ozone/evdev/cursor_delegate_evdev.h |
+++ b/ui/events/ozone/evdev/cursor_delegate_evdev.h |
@@ -20,20 +20,25 @@ class EVENTS_OZONE_EVDEV_EXPORT CursorDelegateEvdev { |
public: |
virtual ~CursorDelegateEvdev() {} |
// Move the cursor. |
virtual void MoveCursor(const gfx::Vector2dF& delta) = 0; |
+ // Move the cursor from the UI thread only. |
virtual void MoveCursorTo(gfx::AcceleratedWidget widget, |
const gfx::PointF& location) = 0; |
+ // Move the cursor from the UI thread only. |
virtual void MoveCursorTo(const gfx::PointF& location) = 0; |
- // Location in screen. |
+ // Location in screen. Either thread, IPC-free. |
virtual gfx::PointF GetLocation() = 0; |
- // Cursor visibility. |
+ // Cursor visibility. Either thread, IPC-free. |
virtual bool IsCursorVisible() = 0; |
- // The bounds that the cursor is confined to. |
+ // The bounds that the cursor is confined to. Either thread, IPC-free. |
virtual gfx::Rect GetCursorConfinedBounds() = 0; |
+ |
+ // Any necessary initialization from Evdev thread. |
+ virtual void InitializeOnEvdev() = 0; |
}; |
} // namespace ui |
@@ -20,20 +20,25 @@ class EVENTS_OZONE_EVDEV_EXPORT CursorDelegateEvdev { |
public: |
virtual ~CursorDelegateEvdev() {} |
- // Move the cursor. |
+ // Move the cursor from the Evdev thread. |
virtual void MoveCursor(const gfx::Vector2dF& delta) = 0; |